@@ -14,7 +14,11 @@ from django.contrib.admin.templatetags.admin_urls import add_preserved_filters
 from django.core.serializers.json import DjangoJSONEncoder
 from django.db import models
 from django.urls import is_valid_path, reverse
-from django.utils.encoding import force_text
+
+try:
+    from django.utils.encoding import force_text
+except:
+    from django.utils.encoding import force_str as force_text
 from django.utils.functional import Promise
 from django.utils.html import format_html
 from django.utils.safestring import mark_safe
@@ -148,6 +152,15 @@ def __get_config(name):
     return value
 
 
+@register.simple_tag
+def get_setting(name):
+    """
+    获取设置项，默认为None
+    自2022.1版本开始增加该方法
+    """
+    return __get_config(name)
+
+
 @register.filter
 def get_config(key):
     return __get_config(key)
@@ -472,7 +485,7 @@ def get_model_url(context):
     request = context.get("request")
 
     key = "{}:{}_{}_changelist".format(
-        request.current_app, opts.app_label, opts.model_name
+        get_current_app(request), opts.app_label, opts.model_name
     )
     url = reverse(key)
     preserved_filters = dict(parse_qsl(context.get("preserved_filters")))
@@ -482,14 +495,24 @@ def get_model_url(context):
     return url
 
 
+def get_current_app(request):
+    app = None
+    if hasattr(request, 'current_app'):
+        app = getattr(request, 'current_app')
+    elif hasattr(request, 'model_admin'):
+        model_admin = getattr(request, 'model_admin')
+        if hasattr(model_admin, 'opts'):
+            opts = getattr(model_admin, 'opts')
+            app = opts.app_config.name
+    return app
+
+
 @register.simple_tag(takes_context=True)
 def get_model_ajax_url(context):
     opts = context.get("opts")
     request = context.get("request")
 
-    key = "{}:{}_{}_changelist".format(
-        request.current_app, opts.app_label, opts.model_name
-    )
+    key = "admin:{}_{}_ajax".format(opts.app_label, opts.model_name)
     try:
         return reverse(key)
     except:
